@@ -5,7 +5,7 @@ import logging
 import math
 from datetime import datetime
 from .parameter import Parameter
-from .tools import handle_date, handle_db_to_list
+from .tools import handle_date, handle_db_to_list, handle_db_dict
 from flask import abort, Response
 from bson import ObjectId
 
@@ -63,6 +63,21 @@ class DBConnect():
             logging.warning(str_data)
             abort(Response(str_data, 500, {}))
 
+    def find_docu(self, find_dict: dict, many: bool = True) -> list:
+        try:
+            if many:
+                # 多文档查询方式
+                query_cursor = self.mongo_collection.find(find_dict)
+                return handle_db_to_list(query_cursor)
+            else:
+                # 单文档查询方式
+                query_dict = self.mongo_collection.find_one(find_dict)
+                return [handle_db_dict(query_dict)]
+        except Exception as err:
+            str_data = 'MongoDB(组件)出现查询错误: {0}'.format(err)
+            logging.warning(str_data)
+            abort(Response(str_data, 500, {}))
+
     def find_docu_by_id(self, id: str, raise_err=True) -> dict:
         """
         根据id查找记录
@@ -96,7 +111,8 @@ class DBConnect():
         """
         if not isinstance(id_list, list):
             logging.warning("类型错误，预期 %s ,却得到 %s" % (list, type(id_list)))
-            abort(Response("类型错误，预期 %s ,却得到 %s" % (list, type(id_list)), 400, {}))
+            abort(Response("类型错误，预期 %s ,却得到 %s" %
+                           (list, type(id_list)), 400, {}))
         id_search = []
         for id in id_list:
             id_search.append({'_id': ObjectId(id)})
