@@ -1,6 +1,7 @@
 import json
 import logging
 from flask import abort, Response
+from .tools import handle_db_id
 
 logging.basicConfig(
     level=logging.WARNING,
@@ -61,4 +62,6 @@ class Parameter():
                 str_data = f'有多余的请求参数: {err}'
                 logging.warning(str_data)
                 abort(Response(str_data, 400, {}))
+        # 从头开始修改请求中的id参数
+        checking = handle_db_id(checking)
         return checking
