@@ -40,19 +40,28 @@ def handle_db_to_list(db_cursor: Cursor) -> list:
         abort(Response(str_data, 500, {}))
     result = []
     for db in db_cursor:
-        db['_id'] = str(db['_id'])
-        db['creation_time'] = int(time.mktime(
-            db['creation_time'].timetuple())) * 1000
-        result.append(dict(db))
+        result.append(handle_db_dict(db_dict=db))
     return result
 
 
+def handle_db_dict(db_dict: dict) -> dict:
+    try:
+        db_dict['_id'] = str(db_dict['_id'])
+        db_dict['creation_time'] = int(time.mktime(
+            db_dict['creation_time'].timetuple())) * 1000
+        return db_dict
+    except Exception as err:
+        str_data = 'MongoDB 数据字典解析异常: {0}'.format(err)
+        logging.warning(str_data)
+        abort(Response(str_data, 500, {}))
+
+
 def handle_db_id(data_dict: dict) -> dict:
     try:
         if data_dict.__contains__('_id'):
             data_dict['_id'] = ObjectId(str(data_dict['_id']))
         return data_dict
     except Exception as err:
-        str_data = 'MongoDB id 格式解析异常: {0}'.format(err)
+        str_data = 'MongoDB _id 格式解析异常: {0}'.format(err)
         logging.warning(str_data)
         abort(Response(str_data, 400, {}))
